library(lattice)
library(car)
library(DHARMa)
library(EnvStats)
library(glmmTMB)
library(ggplot2)
library(RVAideMemoire)



##############################################################
### *** Flowers in flowers strips (Supplementary data) *** ###
##############################################################

rm(list=ls())
flowers <- read.table("...PATH.../FlowersInFlowerstrips.txt",header=T,sep="\t",dec=",")

names(flowers)
str(flowers)
flowers$Site
plot(flowers$Flowers)
boxplot(flowers$Flowers)

library(Cairo)
CairoPS("...PATH.../AppendixFigure1.ps", width=6, height=6)
qplot(flowers$Round, flowers$Flowers) + stat_smooth(method="lm", formula="y~poly(x,2)", se=T) + theme_classic()
dev.off()



################################################################################################
### *** Initial colony weight vs. distance from flower strips and batch number (Methods) *** ###
################################################################################################

rm(list=ls())
bb_weight <- read.table("...PATH.../BumblebeeColonyWeight.txt",header=T,sep="\t",dec=",")

names(bb_weight)
str(bb_weight)
bb_weight $Site
plot(bb_weight $weight_zero)
boxplot(bb_weight $weight_zero)

m0 = glmmTMB(InitialColonyWeight ~ scale(PositionDistance) + (1|Site/Position), data=bb_weight)

res = simulateResiduals(m0)
plot(res)

Anova(m0, type="III")



m0 = glmmTMB(InitialColonyWeight ~ Batch + (1|Site/Position), data=bb_weight, dispformula=~Batch)

res = simulateResiduals(m0)
plot(res)

testZeroInflation(res)

Anova(m0, type="III")



#########################################
### *** Colony growth (Main text) *** ###
#########################################

rm(list=ls())
bb_weight <- read.table("...PATH.../BumblebeeColonyWeight.txt",header=T,sep="\t",dec=",")

names(bb_weight)
str(bb_weight)
bb_weight$Site
plot(bb_weight$Slope)
boxplot(bb_weight$Slope)

xyplot(Slope ~ PositionDistance, data=bb_weight, type=c("p", "r", "smooth"))
xyplot(Slope ~ ArableLand, data=bb_weight, type=c("p", "r", "smooth"))
xyplot(Slope ~ InitialColonyWeight, data=bb_weight, type=c("p", "r", "smooth"))

m0a = glmmTMB(Slope ~ scale(PositionDistance) + scale(I(PositionDistance)^2) + scale(ArableLand) + Batch + scale(InitialColonyWeight) + (1+PositionDistance|Site:Position) + (1|Site/Position), data=bb_weight)

m0b = glmmTMB(Slope ~ scale(PositionDistance) + scale(I(PositionDistance)^2) + scale(ArableLand) + Batch + scale(InitialColonyWeight) + (1|Site/Position), data=bb_weight)

AIC(m0a,m0b)

ranef(m0b)
check_collinearity(m0b)

res=simulateResiduals(m0b)
plot(res)

par(mfrow=c(2,2))
plotResiduals(res, bb_weight$PositionDistance)
plotResiduals(res, bb_weight$ArableLand)
plotResiduals(res, bb_weight$Batch)
plotResiduals(res, bb_weight$InitialColonyWeight)
par(mfrow=c(1,1))

rosnerTest(bb_weight$Slope, k=10) # [-c(43, 44), ]

Anova(m0b, type="III")

m1 = update(m0b, ~.Batch)
Anova(m1, type="III")

m2 = update(m1, ~.-scale(ArableLand))
Anova(m2, type="III")

CairoPS("...Path.../MaintextFigure1a.ps", width=6, height=6)
qplot(bb_weight$PositionDistance, fitted(m2)) + stat_smooth(method="lm", formula="y~poly(x,2)", se=T) + theme_classic()
dev.off()



###############################################
### *** Reproduction yes/no (Main text) *** ###
###############################################

rm(list=ls())
bb_reproduction <- read.table("...PATH.../BumblebeeColonyReproduction.txt",header=T,sep="\t",dec=",")

names(bb_reproduction)
str(bb_reproduction)
bb_reproduction$ReproductionBinomial
plot(bb_reproduction$ReproductionBinomial)
boxplot(bb_reproduction$ReproductionBinomial)

xyplot(ReproductionBinomial ~ PositionDistance, data=bb_reproduction, type=c("p", "r", "smooth"))
xyplot(ReproductionBinomial ~ ArableLand, data=bb_reproduction, type=c("p", "r", "smooth"))
xyplot(ReproductionBinomial ~ InitialColonyWeight, data=bb_reproduction, type=c("p", "r", "smooth"))

m0a = glmmTMB(ReproductionBinomial ~ scale(PositionDistance) + scale(I(PositionDistance)^2) + scale(ArableLand) + Batch + scale(InitialColonyWeight) + (1+PositionDistance|Site:Position) + (1|Site/Position), data=bb_reproduction family=binomial) # convergence problem

m0b = glmmTMB(ReproductionBinomial ~ scale(PositionDistance) + scale(I(PositionDistance)^2) + scale(ArableLand) + Batch + scale(InitialColonyWeight) + (1|Site/Position), data=bb_reproduction, family=binomial)

AIC(m0a,m0b)

ranef(m0b)
check_collinearity(m0b)

res=simulateResiduals(m0b)
plot(res)

par(mfrow=c(2,2))
plotResiduals(res, bb_reproduction$PositionDistance)
plotResiduals(res, bb_reproduction$ArableLand)
plotResiduals(res, bb_reproduction$Batch)
plotResiduals(res, bb_reproduction$InitialColonyWeight)
par(mfrow=c(1,1))

testZeroInflation(res)
testDispersion(res)

rosnerTest(bb_reproduction$ReproductionBinomial, k=10) # [-c(25, 45, 49, 56, 116), ]


Anova(m0b, type="III")

m1 = update(m0b, ~.-Batch)
Anova(m1, type="III")

m2 = update(m1, ~.-scale(ArableLand))
Anova(m2, type="III")

m3 = update(m2, ~.-scale(InitialColonyWeight))
Anova(m3, type="III")



##################################################
### *** Reproduction magnitute (Main text) *** ###
##################################################

rm(list=ls())
bb_col_complete <- read.table("...PATH.../BumblebeeColonyReproduction.txt",header=T,sep="\t",dec=",")

names(bb_reproduction)
str(bb_reproduction)
bb_reproduction$Reproduction
plot(bb_reproduction$Reproduction)
boxplot(bb_reproduction$Reproduction)

xyplot(Reproduction ~ PositionDistance, data=bb_reproduction, type=c("p", "r", "smooth"))
xyplot(Reproduction ~ ArableLand, data=bb_reproduction, type=c("p", "r", "smooth"))
xyplot(Reproduction ~ InitialColonyWeight, data=bb_reproduction, type=c("p", "r", "smooth"))

m0a = glmmTMB(Reproduction ~ scale(PositionDistance) + scale(I(PositionDistance)^2) + scale(ArableLand) + scale(I(ArableLand^2)) + Batch + scale(InitialColonyWeight) + (1+PositionDistance|Site:Position) + (1|Site/Position), data=bb_reproduction, family=nbinom1, ziformula=~1)

m0a = glmmTMB(Reproduction ~ scale(PositionDistance) + scale(I(PositionDistance)^2) + scale(ArableLand) + scale(I(ArableLand^2)) + Batch + scale(InitialColonyWeight) + (1|Site/Position), data=bb_reproduction, family=nbinom1, ziformula=~1)

AIC(m0a,m0b)

ranef(m0b)
check_collinearity(m0b)

res = simulateResiduals(m0b)
plot(res)

par(mfrow=c(2,2))
plotResiduals(res, bb_reproduction$PositionDistance)
plotResiduals(res, bb_reproduction$ArableLand)
plotResiduals(res, bb_reproduction$Batch)
plotResiduals(res, bb_reproduction$InitialColonyWeight)
par(mfrow=c(1,1))

testZeroInflation(res) 
testDispersion(res)

rosnerTest(bb_reproduction$Reproduction, k=10) # [-c(25, 45, 49, 56, 116), ]

Anova(m0b, type="III")

m2 = update(m0b, ~.-scale(InitialColonyWeight))
Anova(m2, type="III")

m3 = update(m2, ~.-scale(I(ArableLand^2)))
Anova(m3, type="III")

m4 = update(m3, ~.-scale(ArableLand))
Anova(m4, type="III")
summary(m4)


# excluding outliers
m5 = update(m4, ~.-scale(I(PositionDistance)^2))
Anova(m5, type="III")
summary(m5)

CairoPS("...PATH.../MaintextFigure1b.ps", width=6, height=6)
qplot(bb_reproduction$PositionDistance, fitted(m4)) + stat_smooth(method="lm", formula="y~poly(x,2)", se=T) + theme_classic()
dev.off()



###################################################
### *** Reproductive efficiency (Main text) *** ###
###################################################

rm(list=ls())
bb_reproductiveefficiency <- read.table("..PATH.../BumblebeeColonyReproductiveEfficiency.txt",header=T,sep="\t",dec=",")

names(bb_reproductiveefficiency)
str(bb_reproductiveefficiency)
bb_reproductiveefficiency$ReproductiveEfficiency
plot(bb_reproductiveefficiency$ReproductiveEfficiency)
boxplot(bb_reproductiveefficiency$ReproductiveEfficiency)

xyplot(ReproductiveEfficiency ~ PositionDistance, data=bb_reproductiveefficiency, type=c("p", "r", "smooth"))
xyplot(ReproductiveEfficiency ~ ArableLand, data=bb_reproductiveefficiency, type=c("p", "r", "smooth"))
xyplot(ReproductiveEfficiency ~ InitialColonyWeight, data=bb_reproductiveefficiency, type=c("p", "r", "smooth"))

m0a = glmmTMB(ReproductiveEfficiency ~ scale(PositionDistance) + scale(I(PositionDistance)^2) + scale(ArableLand) + scale(I(ArableLand^2)) + Batch + scale(InitialColonyWeight) + (1+PositionDistance|Site:Position) + (1|Site/Position), data=bb_reproductiveefficiency, family=tweedie)

m0b = glmmTMB(ReproductiveEfficiency ~ scale(PositionDistance) + scale(I(PositionDistance)^2) + scale(ArableLand) + scale(I(ArableLand^2)) + Batch + scale(InitialColonyWeight) + (1|Site/Position), data=bb_reproductiveefficiency, family=tweedie)

AIC(m0a,m0b)

ranef(m0b)
check_collinearity(m0b)

res = simulateResiduals(m0b)
plot(res)

par(mfrow=c(2,2))
plotResiduals(res, bb_reproductiveefficiency$PositionDistance)
plotResiduals(res, bb_reproductiveefficiency$ArableLand)
plotResiduals(res, bb_reproductiveefficiency$Batch)
plotResiduals(res, bb_reproductiveefficiency$InitialColonyWeight)
par(mfrow=c(1,1))

testZeroInflation(res) 
testDispersion(res)

rosnerTest(bb_reproductiveefficiency$ReproductiveEfficiency, k=10) # [-c(103), ]

Anova(m0b, type="III")

m2 = update(m0b, ~.-scale(InitialColonyWeight))
Anova(m2)

CairoPS("...PATH.../MaintextFigure1c.ps", width=6, height=6)
qplot(bb_reproductiveefficiency$PositinDistance, fitted(m2)) + stat_smooth(method="lm", formula="y~poly(x,2)", se=T) + theme_classic()
dev.off()



#############################################
### *** Worker size - ITD (Main text) *** ###
#############################################

rm(list=ls())
bb_size <- read.table("...PATH.../BumblebeeWorkerSize.txt",header=T,sep="\t",dec=",")

names(bb_size)
str(bb_size)
bb_size$ITD
plot(bb_size$ITD)
boxplot(bb_size$ITD)

xyplot(ITD ~ PositionDistance, data=ITD, type=c("p", "r", "smooth"))
xyplot(ITD ~ ArableLand, data=ITD, type=c("p", "r", "smooth"))
xyplot(ITD ~ InitialColonyWeight, data=ITD, type=c("p", "r", "smooth"))

m0a = glmmTMB(ITD ~ scale(PositionDistance) + scale(I(PositionDistance)^2) + scale(ArableLand) + Batch + scale(InitialColonyWeight) + (1+PositionDistance|Site:Position) + (1|Site/Position), data=bb_size)

m0b = glmmTMB(ITD ~ scale(PositionDistance) + scale(I(PositionDistance)^2) + scale(ArableLand) + Batch + scale(InitialColonyWeight) + (1|Site/Position), data=bb_size)

AIC(m0a,m0b)

ranef(m0b)
check_collinearity(m0b)

par(mfrow=c(2,2))
plotResiduals(res, bb_size$PositionDistance)
plotResiduals(res, bb_size$ArableLand)
plotResiduals(res, bb_size$Batch)
plotResiduals(res, bb_size$InitialColonyWeight)
par(mfrow=c(1,1))

rosnerTest(bb_size$ITD, k=10) # [-c(16), ]

Anova(m0b, type="III")

m2 = update(m0b, ~.-scale(InitialColonyWeight))
Anova(m2, type="III")

m3 = update(m2, ~.-scale(I(PositionDistance)^2))
Anova(m3, type="III")

m4 = update(m3, ~.-scale(PositionDistance))
Anova(m4, type="III")


# excluding outliers
Anova(m0b, type="III")

m1 = update(m0b, ~.-scale(ArableLand))
Anova(m1, type="III")

m2 = update(m1, ~.-scale(I(PositionDistance)^2))
Anova(m2, type="III")

m3 = update(m2, ~.-scale(PositionDistance))
Anova(m3, type="III")

m4 = update(m3, ~.-scale(InitialColonyWeight))
Anova(m4, type="III")



###########################################
### *** Colony activity (Main text) *** ###
###########################################

rm(list=ls())
bb_activity <- read.table("...PATH.../BumblebeeColonyActivity",header=T,sep="\t",dec=",")

names(bb_activity)
str(bb_activity)
bb_activity$AverageActivity
plot(bb_activity$AverageActivity)
boxplot(bb_activity$AverageActivity)

xyplot(AverageActivity ~ PositionDistance, data=bb_activity, type=c("p", "r", "smooth"))
xyplot(AverageActivity ~ ArableLand, data=bb_activity, type=c("p", "r", "smooth"))
xyplot(AverageActivity ~ InitialColonyWeight, data=bb_activity, type=c("p", "r", "smooth"))

m0a = glmmTMB(AverageActivity ~ scale(PositionDistance) + scale(I(PositionDistance)^2) + scale(ArableLand) + Batch + scale(InitialColonyWeight) + (1+PositionDistance|Site) + (1|Site), data=bb_activity, family=tweedie)

m0b = glmmTMB(AverageActivity ~ scale(PositionDistance) + scale(I(PositionDistance)^2) + scale(ArableLand) + Batch + scale(InitialColonyWeight) + (1|Site), data=bb_activity, family=tweedie)

AICc(m0a,m0b)

ranef(m0b)
check_collinearity(m0b)

res = simulateResiduals(m0b)
plot(res)

par(mfrow=c(2,2))
plotResiduals(res, bb_activity$PositionDistance)
plotResiduals(res, bb_activity$ArableLand)
plotResiduals(res, bb_activity$Batch)
plotResiduals(res, bb_activity$InitialColonyWeight)
par(mfrow=c(1,1))

testZeroInflation(res) 
testDispersion(res) 

rosnerTest(bb_activity$Average_Activity, k=10) # [-c(14,16), ]

Anova(m0, type="III")

m1 = update(m0, ~.-scale(InitialColonyWeight))
Anova(m1, type="III")

m2 = update(m1, ~.-scale(I(PositionDistance)^2))
Anova(m2, type="III")

m3 = update(m2, ~.-scale(ArableLand))
Anova(m3, type="III")

CairoPS("...PATH.../MaintextFigure1d.ps", width=6, height=6)
qplot(bb_activity$PositionDistance, fitted(m3)) + stat_smooth(method="lm", formula="y~poly(x,2)", se=T) + theme_classic()
dev.off()


